==> openshift-model-6.1.1-sources.jar: io/fabric8/openshift/api/model/BuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSourceFluent<A extends BuildSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBinary instead.
   * @return The buildable object.
   */
  @Deprecated
  public BinaryBuildSource getBinary();
  public BinaryBuildSource buildBinary();
  public A withBinary(BinaryBuildSource binary);
  public Boolean hasBinary();
  public A withNewBinary(String asFile);
  public BuildSourceFluent.BinaryNested<A> withNewBinary();
  public BuildSourceFluent.BinaryNested<A> withNewBinaryLike(BinaryBuildSource item);
  public BuildSourceFluent.BinaryNested<A> editBinary();
  public BuildSourceFluent.BinaryNested<A> editOrNewBinary();
  public BuildSourceFluent.BinaryNested<A> editOrNewBinaryLike(BinaryBuildSource item);
  public A addToConfigMaps(Integer index,ConfigMapBuildSource item);
  public A setToConfigMaps(Integer index,ConfigMapBuildSource item);
  public A addToConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... items);
  public A addAllToConfigMaps(Collection<ConfigMapBuildSource> items);
  public A removeFromConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... items);
  public A removeAllFromConfigMaps(Collection<ConfigMapBuildSource> items);
  public A removeMatchingFromConfigMaps(Predicate<ConfigMapBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfigMaps instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConfigMapBuildSource> getConfigMaps();
  public List<ConfigMapBuildSource> buildConfigMaps();
  public ConfigMapBuildSource buildConfigMap(Integer index);
  public ConfigMapBuildSource buildFirstConfigMap();
  public ConfigMapBuildSource buildLastConfigMap();
  public ConfigMapBuildSource buildMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public Boolean hasMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public A withConfigMaps(List<ConfigMapBuildSource> configMaps);
  public A withConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... configMaps);
  public Boolean hasConfigMaps();
  public BuildSourceFluent.ConfigMapsNested<A> addNewConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> addNewConfigMapLike(ConfigMapBuildSource item);
  public BuildSourceFluent.ConfigMapsNested<A> setNewConfigMapLike(Integer index,ConfigMapBuildSource item);
  public BuildSourceFluent.ConfigMapsNested<A> editConfigMap(Integer index);
  public BuildSourceFluent.ConfigMapsNested<A> editFirstConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> editLastConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> editMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public String getContextDir();
  public A withContextDir(String contextDir);
  public Boolean hasContextDir();
  public String getDockerfile();
  public A withDockerfile(String dockerfile);
  public Boolean hasDockerfile();
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitBuildSource getGit();
  public GitBuildSource buildGit();
  public A withGit(GitBuildSource git);
  public Boolean hasGit();
  public A withNewGit(String httpProxy,String httpsProxy,String noProxy,String ref,String uri);
  public BuildSourceFluent.GitNested<A> withNewGit();
  public BuildSourceFluent.GitNested<A> withNewGitLike(GitBuildSource item);
  public BuildSourceFluent.GitNested<A> editGit();
  public BuildSourceFluent.GitNested<A> editOrNewGit();
  public BuildSourceFluent.GitNested<A> editOrNewGitLike(GitBuildSource item);
  public A addToImages(Integer index,ImageSource item);
  public A setToImages(Integer index,ImageSource item);
  public A addToImages(io.fabric8.openshift.api.model.ImageSource... items);
  public A addAllToImages(Collection<ImageSource> items);
  public A removeFromImages(io.fabric8.openshift.api.model.ImageSource... items);
  public A removeAllFromImages(Collection<ImageSource> items);
  public A removeMatchingFromImages(Predicate<ImageSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildImages instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ImageSource> getImages();
  public List<ImageSource> buildImages();
  public ImageSource buildImage(Integer index);
  public ImageSource buildFirstImage();
  public ImageSource buildLastImage();
  public ImageSource buildMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public Boolean hasMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public A withImages(List<ImageSource> images);
  public A withImages(io.fabric8.openshift.api.model.ImageSource... images);
  public Boolean hasImages();
  public BuildSourceFluent.ImagesNested<A> addNewImage();
  public BuildSourceFluent.ImagesNested<A> addNewImageLike(ImageSource item);
  public BuildSourceFluent.ImagesNested<A> setNewImageLike(Integer index,ImageSource item);
  public BuildSourceFluent.ImagesNested<A> editImage(Integer index);
  public BuildSourceFluent.ImagesNested<A> editFirstImage();
  public BuildSourceFluent.ImagesNested<A> editLastImage();
  public BuildSourceFluent.ImagesNested<A> editMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public A addToSecrets(Integer index,SecretBuildSource item);
  public A setToSecrets(Integer index,SecretBuildSource item);
  public A addToSecrets(io.fabric8.openshift.api.model.SecretBuildSource... items);
  public A addAllToSecrets(Collection<SecretBuildSource> items);
  public A removeFromSecrets(io.fabric8.openshift.api.model.SecretBuildSource... items);
  public A removeAllFromSecrets(Collection<SecretBuildSource> items);
  public A removeMatchingFromSecrets(Predicate<SecretBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSecrets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretBuildSource> getSecrets();
  public List<SecretBuildSource> buildSecrets();
  public SecretBuildSource buildSecret(Integer index);
  public SecretBuildSource buildFirstSecret();
  public SecretBuildSource buildLastSecret();
  public SecretBuildSource buildMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  public Boolean hasMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  public A withSecrets(List<SecretBuildSource> secrets);
  public A withSecrets(io.fabric8.openshift.api.model.SecretBuildSource... secrets);
  public Boolean hasSecrets();
  public BuildSourceFluent.SecretsNested<A> addNewSecret();
  public BuildSourceFluent.SecretsNested<A> addNewSecretLike(SecretBuildSource item);
  public BuildSourceFluent.SecretsNested<A> setNewSecretLike(Integer index,SecretBuildSource item);
  public BuildSourceFluent.SecretsNested<A> editSecret(Integer index);
  public BuildSourceFluent.SecretsNested<A> editFirstSecret();
  public BuildSourceFluent.SecretsNested<A> editLastSecret();
  public BuildSourceFluent.SecretsNested<A> editMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSourceSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSourceSecret();
  public LocalObjectReference buildSourceSecret();
  public A withSourceSecret(LocalObjectReference sourceSecret);
  public Boolean hasSourceSecret();
  public A withNewSourceSecret(String name);
  public BuildSourceFluent.SourceSecretNested<A> withNewSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> withNewSourceSecretLike(LocalObjectReference item);
  public BuildSourceFluent.SourceSecretNested<A> editSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> editOrNewSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> editOrNewSourceSecretLike(LocalObjectReference item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BinaryNested<N> extends Nested<N>,BinaryBuildSourceFluent<BuildSourceFluent.BinaryNested<N>>{
    public N and();
    public N endBinary();
    
  }
  public interface ConfigMapsNested<N> extends Nested<N>,ConfigMapBuildSourceFluent<BuildSourceFluent.ConfigMapsNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  public interface GitNested<N> extends Nested<N>,GitBuildSourceFluent<BuildSourceFluent.GitNested<N>>{
    public N and();
    public N endGit();
    
  }
  public interface ImagesNested<N> extends Nested<N>,ImageSourceFluent<BuildSourceFluent.ImagesNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface SecretsNested<N> extends Nested<N>,SecretBuildSourceFluent<BuildSourceFluent.SecretsNested<N>>{
    public N and();
    public N endSecret();
    
  }
  public interface SourceSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<BuildSourceFluent.SourceSecretNested<N>>{
    public N and();
    public N endSourceSecret();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/BuildSourceFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSourceFluent<A extends BuildSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBinary instead.
   * @return The buildable object.
   */
  @Deprecated
  public BinaryBuildSource getBinary();
  public BinaryBuildSource buildBinary();
  public A withBinary(BinaryBuildSource binary);
  public Boolean hasBinary();
  public A withNewBinary(String asFile);
  public BuildSourceFluent.BinaryNested<A> withNewBinary();
  public BuildSourceFluent.BinaryNested<A> withNewBinaryLike(BinaryBuildSource item);
  public BuildSourceFluent.BinaryNested<A> editBinary();
  public BuildSourceFluent.BinaryNested<A> editOrNewBinary();
  public BuildSourceFluent.BinaryNested<A> editOrNewBinaryLike(BinaryBuildSource item);
  public A addToConfigMaps(int index,ConfigMapBuildSource item);
  public A setToConfigMaps(int index,ConfigMapBuildSource item);
  public A addToConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... items);
  public A addAllToConfigMaps(Collection<ConfigMapBuildSource> items);
  public A removeFromConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... items);
  public A removeAllFromConfigMaps(Collection<ConfigMapBuildSource> items);
  public A removeMatchingFromConfigMaps(Predicate<ConfigMapBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfigMaps instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConfigMapBuildSource> getConfigMaps();
  public List<ConfigMapBuildSource> buildConfigMaps();
  public ConfigMapBuildSource buildConfigMap(int index);
  public ConfigMapBuildSource buildFirstConfigMap();
  public ConfigMapBuildSource buildLastConfigMap();
  public ConfigMapBuildSource buildMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public Boolean hasMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public A withConfigMaps(List<ConfigMapBuildSource> configMaps);
  public A withConfigMaps(io.fabric8.openshift.api.model.ConfigMapBuildSource... configMaps);
  public Boolean hasConfigMaps();
  public BuildSourceFluent.ConfigMapsNested<A> addNewConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> addNewConfigMapLike(ConfigMapBuildSource item);
  public BuildSourceFluent.ConfigMapsNested<A> setNewConfigMapLike(int index,ConfigMapBuildSource item);
  public BuildSourceFluent.ConfigMapsNested<A> editConfigMap(int index);
  public BuildSourceFluent.ConfigMapsNested<A> editFirstConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> editLastConfigMap();
  public BuildSourceFluent.ConfigMapsNested<A> editMatchingConfigMap(Predicate<ConfigMapBuildSourceBuilder> predicate);
  public String getContextDir();
  public A withContextDir(String contextDir);
  public Boolean hasContextDir();
  public String getDockerfile();
  public A withDockerfile(String dockerfile);
  public Boolean hasDockerfile();
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @Deprecated
  public GitBuildSource getGit();
  public GitBuildSource buildGit();
  public A withGit(GitBuildSource git);
  public Boolean hasGit();
  public A withNewGit(String httpProxy,String httpsProxy,String noProxy,String ref,String uri);
  public BuildSourceFluent.GitNested<A> withNewGit();
  public BuildSourceFluent.GitNested<A> withNewGitLike(GitBuildSource item);
  public BuildSourceFluent.GitNested<A> editGit();
  public BuildSourceFluent.GitNested<A> editOrNewGit();
  public BuildSourceFluent.GitNested<A> editOrNewGitLike(GitBuildSource item);
  public A addToImages(int index,ImageSource item);
  public A setToImages(int index,ImageSource item);
  public A addToImages(io.fabric8.openshift.api.model.ImageSource... items);
  public A addAllToImages(Collection<ImageSource> items);
  public A removeFromImages(io.fabric8.openshift.api.model.ImageSource... items);
  public A removeAllFromImages(Collection<ImageSource> items);
  public A removeMatchingFromImages(Predicate<ImageSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildImages instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ImageSource> getImages();
  public List<ImageSource> buildImages();
  public ImageSource buildImage(int index);
  public ImageSource buildFirstImage();
  public ImageSource buildLastImage();
  public ImageSource buildMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public Boolean hasMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public A withImages(List<ImageSource> images);
  public A withImages(io.fabric8.openshift.api.model.ImageSource... images);
  public Boolean hasImages();
  public BuildSourceFluent.ImagesNested<A> addNewImage();
  public BuildSourceFluent.ImagesNested<A> addNewImageLike(ImageSource item);
  public BuildSourceFluent.ImagesNested<A> setNewImageLike(int index,ImageSource item);
  public BuildSourceFluent.ImagesNested<A> editImage(int index);
  public BuildSourceFluent.ImagesNested<A> editFirstImage();
  public BuildSourceFluent.ImagesNested<A> editLastImage();
  public BuildSourceFluent.ImagesNested<A> editMatchingImage(Predicate<ImageSourceBuilder> predicate);
  public A addToSecrets(int index,SecretBuildSource item);
  public A setToSecrets(int index,SecretBuildSource item);
  public A addToSecrets(io.fabric8.openshift.api.model.SecretBuildSource... items);
  public A addAllToSecrets(Collection<SecretBuildSource> items);
  public A removeFromSecrets(io.fabric8.openshift.api.model.SecretBuildSource... items);
  public A removeAllFromSecrets(Collection<SecretBuildSource> items);
  public A removeMatchingFromSecrets(Predicate<SecretBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSecrets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SecretBuildSource> getSecrets();
  public List<SecretBuildSource> buildSecrets();
  public SecretBuildSource buildSecret(int index);
  public SecretBuildSource buildFirstSecret();
  public SecretBuildSource buildLastSecret();
  public SecretBuildSource buildMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  public Boolean hasMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  public A withSecrets(List<SecretBuildSource> secrets);
  public A withSecrets(io.fabric8.openshift.api.model.SecretBuildSource... secrets);
  public Boolean hasSecrets();
  public BuildSourceFluent.SecretsNested<A> addNewSecret();
  public BuildSourceFluent.SecretsNested<A> addNewSecretLike(SecretBuildSource item);
  public BuildSourceFluent.SecretsNested<A> setNewSecretLike(int index,SecretBuildSource item);
  public BuildSourceFluent.SecretsNested<A> editSecret(int index);
  public BuildSourceFluent.SecretsNested<A> editFirstSecret();
  public BuildSourceFluent.SecretsNested<A> editLastSecret();
  public BuildSourceFluent.SecretsNested<A> editMatchingSecret(Predicate<SecretBuildSourceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSourceSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSourceSecret();
  public LocalObjectReference buildSourceSecret();
  public A withSourceSecret(LocalObjectReference sourceSecret);
  public Boolean hasSourceSecret();
  public A withNewSourceSecret(String name);
  public BuildSourceFluent.SourceSecretNested<A> withNewSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> withNewSourceSecretLike(LocalObjectReference item);
  public BuildSourceFluent.SourceSecretNested<A> editSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> editOrNewSourceSecret();
  public BuildSourceFluent.SourceSecretNested<A> editOrNewSourceSecretLike(LocalObjectReference item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BinaryNested<N> extends Nested<N>,BinaryBuildSourceFluent<BuildSourceFluent.BinaryNested<N>>{
    public N and();
    public N endBinary();
    
  }
  public interface ConfigMapsNested<N> extends Nested<N>,ConfigMapBuildSourceFluent<BuildSourceFluent.ConfigMapsNested<N>>{
    public N and();
    public N endConfigMap();
    
  }
  public interface GitNested<N> extends Nested<N>,GitBuildSourceFluent<BuildSourceFluent.GitNested<N>>{
    public N and();
    public N endGit();
    
  }
  public interface ImagesNested<N> extends Nested<N>,ImageSourceFluent<BuildSourceFluent.ImagesNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface SecretsNested<N> extends Nested<N>,SecretBuildSourceFluent<BuildSourceFluent.SecretsNested<N>>{
    public N and();
    public N endSecret();
    
  }
  public interface SourceSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<BuildSourceFluent.SourceSecretNested<N>>{
    public N and();
    public N endSourceSecret();
    
  }
  
}
